//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSCVARC_H
#define WSCVARC_H

#include <WScom.h>
#include <WSCvpolyAttr.h>
#define WSCvarc_VER	1020

class WSCvarc   :public WSCvpolyAttr{

  protected:
    short   _angle1;
    short   _angle2;
    char    _arc_type;

    WSMFpropertyDef(WSNangle1,  short, _angle1  );
    WSMFpropertyDef(WSNangle2,  short, _angle2  );
    WSMFpropertyDef(WSNarcType, char,  _arc_type);

  public:
    WSDLEX32 WSCvarc(WSCbase* base, char* name);
    WSDLEX32 virtual ~WSCvarc();
    WSDLEX32 virtual long draw();

    WSMFguiClassDef(WSCvarc ,WSCvpolyAttr);
    WSMFversionDef  (WSCvarc);
};
#endif
